<?php

/**
 * Custom Entity admin
 */
class CreditTypeEntityUIController extends EntityDefaultUIController {

  public $overviewPagerLimit = 0;

  public function overviewTable($conditions = array()) {
    $sort_params = drupal_get_query_parameters();
    $sort = isset($sort_params['sort']) ? $sort_params['sort'] : 'DESC';
    $order = isset($sort_params['order']) ? $sort_params['order'] : 'active';

    $query = new EntityFieldQuery();
    $query->entityCondition('entity_type', $this->entityType);

    // Add all conditions to query.
    foreach ($conditions as $key => $value) {
      $query->propertyCondition($key, $value);
    }

    if ($this->overviewPagerLimit) {
      $query->pager($this->overviewPagerLimit);
    }
    $query->propertyOrderBy(strtolower($order), strtolower($sort));
    $query->propertyOrderBy('weight');
    $query->propertyOrderBy('title');

    $results = $query->execute();

    $ids = isset($results[$this->entityType]) ? array_keys($results[$this->entityType]) : array();
    $entities = $ids ? entity_load($this->entityType, $ids) : array();

    $rows = array();
    foreach ($entities as $entity) {
      $rows[] = $this->overviewTableRow($conditions, entity_id($this->entityType, $entity), $entity);
    }

    $render = array(
      '#theme' => 'table',
      '#header' => $this->overviewTableHeaders($conditions, $rows),
      '#rows' => $rows,
      '#sticky' => FALSE,
      '#empty' => t('None.'),
    );
    return $render;
  }

  protected function overviewTableHeaders($conditions, $rows, $additional_header = array()) {
    $additional_header[] = array(
      'data' => 'Active',
      'type' => 'property',
      'specifier' => 'active',
      'field' => 'active',
    );
    $additional_header[] = 'Is child credit';
    $additional_header[] = 'Assigned child credits';
    $header = parent::overviewTableHeaders($conditions, $rows, $additional_header);
    $header[] = 'Weight';
    return $header;
  }

  protected function overviewTableRow($conditions, $id, $entity, $additional_cols = array()) {
    $values = json_decode($entity->export(), 1);
    // Enabled and Variable cols
    $additional_cols[] = array('data' => $values['active'] ? 'Yes' : 'No', 'field' => 'active');
    $additional_cols[] = $values['sub'] ? 'Yes' : 'No';
    // Child credits
    $sub_credits = [];
    if (isset($values['data']['sub_credits']) && is_array($values['data']['sub_credits'])) {
      foreach ($values['data']['sub_credits'] as $sub) {
        if (!empty($sub)) {
          $sub_credits[] = course_credit_get_credit_type($sub)->title;
        }
      }
    }
    $additional_cols[] = theme_item_list(array('items' => $sub_credits, 'title' => NULL, 'type' => 'ul', 'attributes' => array('type' => 'none')));
    $rows = parent::overviewTableRow($conditions, $id, $entity, $additional_cols);
    $rows[] = l(t('conditions'), "{$this->path}/conditions/manage/course_credit_eligibility_{$id}");
    $rows[] = $values['weight'];
    return $rows;
  }

// Add a column for a new action
  protected function operationCount() {
    return parent::operationCount() + 1;
  }

}
