<?php

/**
 * Field handler for course credit title.
 */
class views_handler_field_course_credit_awarded_child_credits extends views_handler_field_prerender_list {

  /**
   * Working with node table, adding active credit types to it.
   */
  function construct() {
    parent::construct();
    $this->additional_fields['awarded_child_credits'] = array(
      'table' => 'course_credit_awarded',
      'field' => 'ccaid',
    );
  }

  /**
   * Add fields, alias.
   */
  function query() {
    $this->add_additional_fields();
    $this->field_alias = $this->aliases['awarded_child_credits'];
  }

  /**
   * Get the active credit types on each of the nodes in this view.
   */
  function pre_render(&$values) {
    $items = [];
    $ccaids = [];
    foreach ($values as $value) {
      $ccaids[] = $value->{$this->field_alias};
    }

    if ($ccaids) {
      // Query to get all child credit.
      $query = db_select('course_credit_awarded', 'cca')
        ->fields('cct', ['title'])
        ->fields('cca', [])
        ->condition('pid', $ccaids);
      $query->join('course_credit_type', 'cct', 'cca.type = cct.type');
      $result = $query->execute()->fetchAll();
      foreach ($result as $row) {
        foreach ($row as $key => $value) {
          $items[$row->pid][0][$row->ccaid]["[$key]"] = $value;
        }
      }

      $this->items = $items;
    }
  }

  /**
   * Render each credit title.
   *
   * This will use tokens on the field if provided.
   */
  function render_item($count, $item) {
    $pattern = $this->options['course_credit_types_format'];
    if (!$pattern) {
      $pattern = '[credits] [title]';
    }
    $out = '';
    foreach ($item as $row) {
      $credit = strtr($pattern, $row);
      $attributes = ['class' => ['course-credit-' . drupal_html_class($row['[type]']), 'course-child-credit']];
      $out .= '<div ' . drupal_attributes($attributes) . '>' . $credit . '</div>';
    }
    return $out;
  }

  /**
   * Declare options.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['course_credit_types_format'] = array('default' => '');
    return $options;
  }

  /**
   * Select credit types to show.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['course_credit_types_format'] = array(
      '#title' => 'Format',
      '#type' => 'textfield',
      '#description' => 'Specify a format to use other than the name of the active credit type. Possible tokens: [title] [type] [min] [max]. You can also use [min-s] or [max-s] for the "S" after "credit" based on the number of credits.',
      '#default_value' => $this->options['course_credit_types_format'] ? $this->options['course_credit_types_format'] : '[credits] [title]',
    );
  }

}
